@@ -2,6 +2,7 @@
 import os
 import sys
 import logging
+import traceback
 from io import open
 import jaydebeapi
 import re
@@ -83,10 +84,10 @@ class SQLCli(object):
         # 加载数据库驱动
         register_special_command(
             self.load_driver,
-            ".load",
-            ".load",
+            ".loaddriver",
+            ".loaddriver",
             "load JDBC driver .",
-            aliases=("load", "\\l"),
+            aliases=("loaddriver", "\\l"),
         )
 
         # 连接数据库
@@ -135,7 +136,7 @@ class SQLCli(object):
             load_parameters = str(arg).split()
             if len(load_parameters) != 2:
                 self.logger.debug('arg = ' + str(load_parameters))
-                raise SQLCliException("Missing required argument, load [driver file name] [driver class name].")
+                raise SQLCliException("Missing required argument, loaddriver [driver file name] [driver class name].")
             if not os.path.exists(str(load_parameters[0])):
                 raise SQLCliException("driver file [" + str(arg) + "] does not exist.")
 
@@ -224,6 +225,8 @@ class SQLCli(object):
                                               self.jar_file, )
             self.sqlexecute.set_connection(self.db_conn)
         except Exception as e:  # Connecting to a database fail.
+            print('traceback.print_exc():\n%s' % traceback.print_exc())
+            print('traceback.format_exc():\n%s' % traceback.format_exc())
             raise SQLCliException(repr(e))
 
         yield (
@@ -405,7 +408,7 @@ class SQLCli(object):
             # 则直接加载
             if "SQLCLI_CONNECTION_JAR_NAME" in os.environ and \
                     "SQLCLI_CONNECTION_CLASS_NAME" in os.environ:
-                one_iteration('load ' +
+                one_iteration('loaddriver ' +
                               os.environ["SQLCLI_CONNECTION_JAR_NAME"] + ' ' + os.environ[
                                   "SQLCLI_CONNECTION_CLASS_NAME"])
                 iterations += 1
